from .openvkapi import *


class likes:

    @staticmethod
    def add(client, owner_id, item_id):
        response = http.get(f'https://{client["instance"]}/method/Likes.add?type=post&owner_id={owner_id}&item_id={item_id}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def delete(client, owner_id, item_id):
        response = http.get(f'https://{client["instance"]}/method/Likes.delete?type=post&owner_id={owner_id}&item_id={item_id}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def is_liked(client, user_id, owner_id, item_id):
        response = http.get(f'https://{client["instance"]}/method/Likes.remove?user_id={user_id}&type=post&owner_id={owner_id}&item_id={item_id}&access_token={client["token"]}')
        return json.loads(response.text)


from .openvkapi import *


class messages:

    @staticmethod
    def send(client, user_id, message, peer_id=-1, domain='', chat_id=-1, user_ids='', sticker_id=-1):
        response = http.get(f'https://{client["instance"]}/method/Messages.send?user_id={user_id}&peer_id={peer_id}&message={message}%domain={domain}%chat_id={chat_id}&user_ids={user_ids}&sticker_id={sticker_id}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def delete(client, message_id):
        response = http.get(f'https://{client["instance"]}/method/Messages.delete?messages_ids={message_id}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def restore(client, message_id):
        response = http.get(f'https://{client["instance"]}/method/Messages.restore?messages_ids={message_id}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def get_conversations(client, offset=0, count=20, filter="all", extended=0):
        response = http.get(f'https://{client["instance"]}/method/Messages.getConversations?offset={offset}&count={count}&filter={filter}&extended={extended}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def get_history(client, user_id, offset=0, count=20, peer_id=-1, start_message_id=0, rev=0, extended=0):
        response = http.get(f'https://{client["instance"]}/method/Messages.getHistory?user_id={user_id}&offset={offset}&count={count}&peer_id={peer_id}&start_message_id={start_message_id}&rev={rev}&extended={extended}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def get_long_poll_history(client):
        response = http.get(f'https://{client["instance"]}/method/Messages.getLongPollHistory?access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def get_long_poll_server(client):
        response = http.get(f'https://{client["instance"]}/method/Messages.getLongPollServer?access_token={client["token"]}')
        return json.loads(response.text)


"""
:author: Parliskaya
:license: MIT License, see LICENSE file

:copyright: (c) 2022 Parliskaya
"""

from .openvkapi import *
from .account import account
from .friends import friends
from .groups import groups
from .messages import messages
from .ovk import ovk
from .utils import utils
from .users import users
from .news_feed import news_feed
from .wall import wall
from .likes import likes


__author__ = 'Parliskaya'
__version__ = '1.4'
__email__ = 'alonaparlis@gmail.com'


from .openvkapi import *


class friends:

    @staticmethod
    def get(client, user_id, fields='', offset=0, count=100):
        response = http.get(f'https://{client["instance"]}/method/Friends.get?user_id={user_id}&fields={fields}&offset={offset}&count={count}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def add(client, user_id):
        response = http.get(f'https://{client["instance"]}/method/Friends.add?user_id={user_id}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def remove(client, user_id):
        response = http.get(f'https://{client["instance"]}/method/Friends.remove?user_id={user_id}&access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def get_list(client):
        response = http.get(f'https://{client["instance"]}/method/Friends.getLists?access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def list(client, value):
        if value == 0:
            response = http.get(f'https://{client["instance"]}/method/Friends.edit?access_token={client["token"]}')
            return json.loads(response.text)

        elif value == 1:
            response = http.get(f'https://{client["instance"]}/method/Friends.deleteList?access_token={client["token"]}')
            return json.loads(response.text)

        elif value == 2:
            response = http.get(f'https://{client["instance"]}/method/Friends.editList?access_token={client["token"]}')
            return json.loads(response.text)

        else:
            pass



from .openvkapi import *


class wall:

    @staticmethod
    def get(client, user_id: int, offset=0, count=100, extended=0):
        response = http.get(f'https://{client["instance"]}/method/Wall.get?owner_id={user_id}&offset={offset}&count={count}&extended={extended}&access_token={client["token"]}')
        return json.loads(response.text)['response']

    @staticmethod
    def get_post(client, post_id: int, fields='', extended=0):
        response = http.get(f'https://{client["instance"]}/method/Wall.getById?posts={post_id}&fields={fields}&extended={extended}&access_token={client["token"]}')
        return json.loads(response.text)['response']

    @staticmethod
    def post(client, user_id: int, message: str, from_group=0, signed=0):
        response = http.get(f'https://{client["instance"]}/method/Wall.post?message={message}&owner_id={user_id}&from_group={from_group}&signed={signed}&access_token={client["token"]}')
        return json.loads(response.text)['response']


from .openvkapi import *


class news_feed:

    @staticmethod
    def get(client, offset=0, count=100, extended=0):
        response = http.get(f'https://{client["instance"]}/method/Newsfeed.get?offset={offset}&count={count}&extended={extended}&access_token={client["token"]}')
        return json.loads(response.text)['response']


import requests as http
import json


class openvkapi:

    """Авторизация пользователя"""

    @staticmethod
    def auth(login: str, password: str, instance='openvk.su', code=0):
        response = http.get(f'https://{instance}/token?username={login}&password={password}&code={code}&grant_type=password')
        token = str(json.loads(response.text)['access_token'])
        user_id = int(json.loads(response.text)['user_id'])
        response = {
            'instance': instance,
            'token': token,
            'id': user_id
        }
        return response

    @staticmethod
    def lenas():
        print('Вы потрогали Утинку за ляшки через Api')



from .openvkapi import *


class users:

    @staticmethod
    def get(client, user_id, fields='', offset=0, count=100):
        response = http.get(f'https://{client["instance"]}/method/Users.get?user_ids={user_id}&fields={fields}&offset={offset}&count={count}&access_token={client["token"]}')
        return json.loads(response.text)['response']

    @staticmethod
    def get_followers(client, user_id, fields='', offset=0, count=100):
        response = http.get(f'https://{client["instance"]}/method/Users.getFollowers?user_id={user_id}&fields={fields}&offset={offset}&count={count}&access_token={client["token"]}')
        return json.loads(response.text)['response']

    @staticmethod
    def search(client, q, fields='', offset=0, count=100):
        response = http.get(f'https://{client["instance"]}/method/Users.search?q={q}&fields={fields}&offset={offset}&count={count}&access_token={client["token"]}')
        return json.loads(response.text)['response']


from .openvkapi import *


class groups:

    @staticmethod
    def get(client, user_id, fields='', offset=0, count=100):
        response = http.get(f'https://{client["instance"]}/method/Groups.get?user_id={user_id}&fields={fields}&offset={offset}&count={count}&access_token={client["token"]}')
        return json.loads(response.text)


from .openvkapi import *


class account:

    @staticmethod
    def get_profile(client):
        response = http.get(f'https://{client["instance"]}/method/Account.getProfileInfo?access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def get_info(client):
        response = http.get(f'https://{client["instance"]}/method/Account.getInfo?access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def set_online(client, status):
        if status == 0:
            return http.get(f'https://{client["instance"]}/method/Account.setOffline?access_token={client["token"]}')
        elif status == 1:
            return http.get(f'https://{client["instance"]}/method/Account.setOnline?access_token={client["token"]}')
        else:
            pass

    @staticmethod
    def get_permissions(client):
        response = http.get(f'https://{client["instance"]}/method/Account.getAppPermissions?access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def get_counters(client):
        response = http.get(f'https://{client["instance"]}/method/Account.getCounters?access_token={client["token"]}')
        return json.loads(response.text)



from .openvkapi import *


class ovk:

    @staticmethod
    def version(client):
        response = http.get(f'https://{client["instance"]}/method/Ovk.version?access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def test(client):
        response = http.get(f'https://{client["instance"]}/method/Ovk.test?access_token={client["token"]}')
        return json.loads(response.text)

    @staticmethod
    def chicken_wings(client):
        response = http.get(f'https://{client["instance"]}/method/Ovk.chickenWings?access_token={client["token"]}')
        return json.loads(response.text)
 
     @staticmethod
    def about_instance(client):
        response = http.get(f'https://{client["instance"]}/method/Ovk.aboutInstance?access_token={client["token"]}')
        return json.loads(response.text)


from io import open
from setuptools import setup

"""
:author: Parliskaya
:license: MIT License, see LICENSE file

:copyright: (c) 2022 Parliskaya
"""


version = '1.4'
'''
with open('README.md', encoding='utf-8') as f:
	long_description = f.read()
'''

long_description = '''Python module for OpenVK API project management platform (OpenVK API wrapper)'''

setup(
	name='openvk',
	version=version,

	author='Parliskaya',
	author_email='alonaparlis@gmail.com',

	description=(
		u'Python module for writing scripts for project management platform',
		u'OpenVK (openvk.su API wrapper)'
	),
	long_description=long_description,
	long_description_content_type='text/markdown',

	url='https://github.com/Parliskaya/openvkapi',
	download_url='https://github.com/Parliskaya/openvkapi/archive/v{}.zip'.format(version),

	license='MIT License, see LICENSE file',

	packages=['openvk'],
	install_requires=['requests'],

	classifiers=[
		'License :: OSI Approved :: MIT License',
		'Operating System :: OS Independent',
		'Intended Audience :: End Users/Desktop',
		'Intended Audience :: Developers',
		'Programming Language :: Python',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.8',
		'Programming Language :: Python :: Implementation :: PyPy',
		'Programming Language :: Python :: Implementation :: CPython',
	]
)


from .openvkapi import *


class utils:

    @staticmethod
    def get_server_time(client):
        response = http.get(f'https://{client["instance"]}/method/Utils.getServerTime?access_token={client["token"]}')
        return json.loads(response.text)['response']